"""
src rpmheader handler
"""
import sys
import DistroDbMaker
import DistroDbMaker.Map
sourceurl=DistroDbMaker.Map.MapOne2One();
srcversion=DistroDbMaker.Map.MapOne2One();
srcsummary=DistroDbMaker.Map.MapOne2One();
srcdescription=DistroDbMaker.Map.MapOne2One();
srcfilepath=DistroDbMaker.Map.MapOne2One();
requires=DistroDbMaker.Map.MapOne2Many();

def process_requires(requirename,pkgname):
    if not requirename[:7] == b'rpmlib(':
        requires.add_pair(requirename,pkgname)

class SrcRPM2DistroDB(DistroDbMaker.RPM2DistroDB):

    def __init__(self, verbose=0, write_src_summary_description=0):
        super(SrcRPM2DistroDB,self).__init__(verbose)
        self.write_src_summary_description=write_src_summary_description

    def process_rpm_header(self,rpmheader,isSource=True, filepath=None):
        verbose=self.verbose
        debug=self.debug
        name=rpmheader['NAME']
        if not isSource:
            raise ValueError("Oops! header for %s is not from a source package" % (name))
        if self.name_filter and not name in self.name_filter:
            return
        if self.debug:
            print ("process_rpm_header %s: got %s" % (name,rpmheader))
        if self.exclude_nosrc:
            if filepath==None:
                raise ValueError('filepath for %s is None, but exclude_nosrc require filepath' % (name))
            else:
                if filepath[-10:] == b'.nosrc.rpm':
                    return
        version=rpmheader['VERSION']
        srcversion.add_pair(name,version)
        url=rpmheader['URL']
        if url:
            sourceurl.add_pair(name,url)
        if self.write_src_summary_description:
            summary=rpmheader['SUMMARY']
            if summary:
                srcsummary.add_pair(name,summary)
            desc=rpmheader['DESCRIPTION']
            if filepath:
                srcfilepath.add_pair(name,filepath)
        req=rpmheader['REQUIRENAME']
        if req:
            for p in req:
                process_requires(p,name)
        elif debug:
            print ("info: %s has no buildrequires" % (name))

    def write_distrodb(self, distrodb):
        distrodb.writemap('buildrequires.raw',requires)
        distrodb.writemap('sourceurl.raw',sourceurl)
        distrodb.writemap('srcversion.raw',srcversion)
        if self.write_src_summary_description:
            distrodb.writemap('srcsummary.raw',srcsummary)
            distrodb.writemap('srcdescription.raw',srcdescription)
            distrodb.writemap('srcfilepath.raw',srcfilepath)

